Welcome to ``stitch_core``'s documentation!
===========================================

``stitch_core`` is a Python library for running the abstraction learning tool `stitch <https://github.com/mlb2251/stitch>`_
from the paper `Top-Down Synthesis for Library Learning <https://arxiv.org/abs/2211.16605>`_ (POPL 2023).

Contents
========

.. toctree::
   :maxdepth: 1

   intro/install
   intro/tutorial
   api
   compress_kwargs
   out_json
   cost_metrics
   compression_objectives